@@ -95,6 +95,20 @@ class ConfigHelper:
         except ValueError:
             return False
 
+    def get_download_lessons(self) -> bool:
+        # returns a stored boolean if lessons should be downloaded
+        try:
+            return self.get_property('download_lessons')
+        except ValueError:
+            return False
+
+    def get_download_workshops(self) -> bool:
+        # returns a stored boolean if workshops should be downloaded
+        try:
+            return self.get_property('download_workshops')
+        except ValueError:
+            return False
+
     def get_userid_and_version(self) -> (str, int):
         # returns the userid and a version
         try:
