@@ -3,6 +3,7 @@ import os
 import platform
 import ssl
 import time
+import shlex
 import socket
 import shutil
 import urllib
@@ -10,6 +11,7 @@ import logging
 import posixpath
 import traceback
 import threading
+import subprocess
 import contextlib
 
 from pathlib import Path
@@ -432,7 +434,64 @@ class URLTarget(object):
             if len(found_names) > 0:
                 new_filename = unquote(found_names[0])
 
-        if isHTML and not self.is_blocked_for_youtube_dl(url_to_download):
+        external_file_downloaders = self.options.get('external_file_downloaders', {})
+        external_file_downloader = external_file_downloaders.get(url_parsed.netloc, "")
+        if isHTML and external_file_downloader != "":
+            # This link is to be downloaded from an external program.
+            cmd = external_file_downloader.replace('%U', url_to_download)
+            logging.debug(
+                'T%s - Run external downloader using the following command: `%s`',
+                self.thread_id,
+                cmd,
+            )
+            external_dl_failed_with_error = False
+
+            try:
+                p = subprocess.Popen(
+                    shlex.split(cmd),
+                    cwd=str(self.destination),
+                    stderr=subprocess.PIPE,
+                    stdout=subprocess.PIPE,
+                    universal_newlines=True,
+                )
+
+                for line in p.stdout:
+                    # line = line.decode('utf-8', 'replace')
+                    self.thread_report[self.thread_id]['external_dl'] = line.replace('\n', '').replace('\r', '')
+
+                _, stderr = p.communicate()
+
+                if p.returncode != 0:
+                    external_dl_failed_with_error = True
+            except Exception as e:
+                stderr = str(e)
+                external_dl_failed_with_error = True
+
+            if external_dl_failed_with_error:
+                logging.error('T%s - External Downloader Error: %s', self.thread_id, stderr)
+                if not delete_if_successful:
+                    # cleanup the url-link file
+                    try:
+                        os.remove(self.file.saved_to)
+                    except Exception as e:
+                        logging.warning(
+                            'T%s - Could not delete %s after external downloader failed. Error: %s',
+                            self.thread_id,
+                            self.file.saved_to,
+                            e,
+                        )
+                self.success = False
+                raise RuntimeError(
+                    'The external downloader could not download the URL.'
+                    + ' For details, see the error messages in the log file.'
+                )
+            else:
+                self.file.saved_to = str(Path(self.destination) / self.filename)
+                self.file.time_stamp = int(time.time())
+                self.success = True
+                return True
+
+        elif isHTML and not self.is_blocked_for_youtube_dl(url_to_download):
 
             filename_tmpl = self.filename + ' - %(title)s (%(id)s).%(ext)s'
             if self.file.content_type == 'description-url':
@@ -460,7 +519,6 @@ class URLTarget(object):
             add_additional_extractors(ydl)
 
             videopasswords = self.options.get('videopasswords', {})
-
             password_list = videopasswords.get(url_parsed.netloc, [])
             if not type(password_list) is list:
                 password_list = [password_list]
@@ -662,6 +720,34 @@ class URLTarget(object):
 
             self.success = True
 
+    def create_html_file(self):
+        """
+        Creates a HTML file
+        """
+        logging.debug('T%s - Creating a html file', self.thread_id)
+        html_file = open(self.file.saved_to, 'w+', encoding='utf-8')
+        to_save = ""
+        if self.file.html_content is not None:
+            to_save = self.file.html_content
+
+            if to_save != '':
+                html_file.write(to_save)
+
+        html_file.close()
+
+        if to_save == '':
+            logging.debug('T%s - Remove target file because html file would be empty', self.thread_id)
+            os.remove(self.file.saved_to)
+
+            self.file.time_stamp = int(time.time())
+
+            self.success = True
+        else:
+            self.set_utime()
+            self.file.time_stamp = int(time.time())
+
+            self.success = True
+
     def try_move_file(self) -> bool:
         """
         It will try to move the old file to the new location.
@@ -737,6 +823,7 @@ class URLTarget(object):
         self.thread_report[self.thread_id]['percentage'] = 0
         self.thread_report[self.thread_id]['extra_totalsize'] = None
         self.thread_report[self.thread_id]['current_url'] = self.file.content_fileurl
+        self.thread_report[self.thread_id]['external_dl'] = None
         self.youtube_dl_failed_with_error = False
 
         try:
@@ -762,6 +849,12 @@ class URLTarget(object):
                 self.create_description()
                 return self.success
 
+            # if it is a HTML-File we have to create a HTML file
+            # instead of downloading it
+            if self.file.content_type == 'html':
+                self.create_html_file()
+                return self.success
+
             add_token = True
             if self.file.module_modname.startswith('index_mod'):
                 add_token = True
